==> kdevelop-php-docs_1.7.1.orig.tar.xz: kdevelop-php-docs-1.7.1/kdevphpdocs.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=This plugin integrates PHP.net online documentation.
Comment[bs]=Ovaj dodatak integriše PHP.net mrežnu dokumentaciju.
Comment[ca]=Aquest connector integra documentació en línia de PHP.net.
Comment[ca@valencia]=Este connector integra documentació en línia de PHP.net.
Comment[cs]=Tento modul integruje online dokumentaci PHP.net.
Comment[da]=Dette plugin integrerer online dokumentation fra PHP.net.
Comment[de]=Dieses Modul integriert die PHP.net-Online-Dokumentation.
Comment[el]=Αυτό το πρόσθετο ενσωματώνει την τεκμηρίωση από το php.net .
Comment[en_GB]=This plugin integrates PHP.net online documentation.
Comment[es]=Este complemento integra la documentación en línea de PHP.net.
Comment[et]=See plugin lõimib PHP veebidokumentatsiooni.
Comment[fi]=Tämä liitännäinen integroi PHP.net-dokumentaation.
Comment[fr]=Ce module externe intègre la documentation en ligne « PHP.net ».
Comment[ga]=Comhtháthaíonn an breiseán seo doiciméadú ar líne PHP.net.
Comment[gl]=Esta extensión integra a documentación en liña de PHP.net
Comment[hu]=Ez a bővítmény integrálja a PHP.net webes dokumentációját.
Comment[it]=Questa estensione integra la documentazione online PHP.net
Comment[ja]=このプラグインは、PHP.net のオンラインドキュメントを統合します。
Comment[kk]=Бұл PHP.net онлайн құжаттамасын оқу плагині.
Comment[ko]=PHP.net 온라인 문서를 통합합니다.
Comment[lt]=Šis priedas integruoja PHP.net dokumentaciją esančią tinkle.
Comment[mr]=हा प्लगइन PHP.net ऑनलाइन दस्तऐवजीकरणाचे एकीकरण करतो.
Comment[ms]=Plugin ini mengintegrasikan dokumentasi dalam talian PHP.net
Comment[nb]=Dette programtillegget integrerer dokumentasjon på nettverket for PHP.net
Comment[nds]=Dit Moduul bett de Online-Dokmentatschoon vun PHP.net in.
Comment[nl]=Deze plugin integreert PHP.net online-documentatie.
Comment[pl]=Wtyczka ta integruje dokumentację internetową PHP.net.
Comment[pt]=Este 'plugin' integra a documentação 'online' do PHP.net.
Comment[pt_BR]=Este plugin integra a documentação on-line do PHP.net.
Comment[ru]=Расширение для работы с документацией с сайта PHP.net
Comment[sk]=Tento plugin integruje online dokumentáciu PHP.net.
Comment[sl]=Ta vstavek vključuje spletno dokumentacijo za PHP.
Comment[sv]=Insticksprogrammet integrerar PHP.net nätdokumentation.
Comment[tr]=Bu eklenti, PHP çevrimiçi belgelendirmesini entegre eder.
Comment[ug]=بۇ قىستۇرما PHP.net نىڭ توردىكى پۈتۈكلىرىنى يۈرۈشلەشتۈرىدۇ.
Comment[uk]=За допомогою цього додатка можна інтегрувати документацію PHP.net.
Comment[x-test]=xxThis plugin integrates PHP.net online documentation.xx
Comment[zh_CN]=此插件集成了 PHP.net 的在线文档。
Comment[zh_TW]=此外掛程式整合 PHP.net 線上文件。
Name=PHP Documentation
Name[bs]=PHP Dokumentacija
Name[ca]=Documentació de PHP
Name[ca@valencia]=Documentació de PHP
Name[cs]=Dokumentace PHP
Name[da]=PHP-dokumentation
Name[de]=PHP-Dokumentation
Name[el]=Τεκμηρίωση για PHP
Name[en_GB]=PHP Documentation
Name[es]=Documentación de PHP
Name[et]=PHP dokumentatsioon
Name[fi]=PHP-dokumentaatio
Name[fr]=Documentation de PHP
Name[ga]=Doiciméadú PHP
Name[gl]=Documentación de PHP
Name[hu]=PHP dokumentáció
Name[it]=Documentazione PHP
Name[ja]=PHP ドキュメント
Name[kk]=PHP құжаттамасы
Name[ko]=PHP 문서
Name[lt]=PHP dokumentacija
Name[mr]=पीएचपी दस्तऐवजीकरण
Name[ms]=Dokumentasi PHP
Name[nb]=PHP-dokumentasjon
Name[nds]=PHP-Dokmentatschoon
Name[nl]=PHP-documentatie
Name[pl]=Dokumentacja PHP
Name[pt]=Documentação de PHP
Name[pt_BR]=Documentação de PHP
Name[ru]=Документация по PHP
Name[sk]=Dokumentácia PHP
Name[sl]=Dokumentacija za PHP
Name[sv]=PHP-dokumentation
Name[tr]=PHP Belgelendirmesi
Name[ug]=PHP پۈتۈكلىرى
Name[uk]=Документація з PHP
Name[x-test]=xxPHP Documentationxx
Name[zh_CN]=PHP 文档
Name[zh_TW]=PHP 文件
ServiceTypes=KDevelop/Plugin

X-KDE-Library=kdevphpdocs
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevphpdocs
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Documentation
X-KDevelop-Mode=GUI
X-KDevelop-Interfaces=org.kdevelop.IDocumentationProvider

==> kdevelop-php-docs-1.7.2.tar.xz: kdevelop-php-docs-1.7.2/kdevphpdocs.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=This plugin integrates PHP.net online documentation.
Comment[bs]=Ovaj dodatak integriše PHP.net mrežnu dokumentaciju.
Comment[ca]=Aquest connector integra documentació en línia de PHP.net.
Comment[ca@valencia]=Este connector integra documentació en línia de PHP.net.
Comment[cs]=Tento modul integruje online dokumentaci PHP.net.
Comment[da]=Dette plugin integrerer online dokumentation fra PHP.net.
Comment[de]=Dieses Modul integriert die PHP.net-Online-Dokumentation.
Comment[el]=Αυτό το πρόσθετο ενσωματώνει την τεκμηρίωση από το php.net .
Comment[en_GB]=This plugin integrates PHP.net online documentation.
Comment[es]=Este complemento integra la documentación en línea de PHP.net.
Comment[et]=See plugin lõimib PHP veebidokumentatsiooni.
Comment[fi]=Tämä liitännäinen integroi PHP.net-dokumentaation.
Comment[fr]=Ce module externe intègre la documentation en ligne « PHP.net ».
Comment[ga]=Comhtháthaíonn an breiseán seo doiciméadú ar líne PHP.net.
Comment[gl]=Esta extensión integra a documentación en liña de PHP.net
Comment[hu]=Ez a bővítmény integrálja a PHP.net webes dokumentációját.
Comment[it]=Questa estensione integra la documentazione online PHP.net
Comment[ja]=このプラグインは、PHP.net のオンラインドキュメントを統合します。
Comment[kk]=Бұл PHP.net онлайн құжаттамасын оқу плагині.
Comment[ko]=PHP.net 온라인 문서를 통합합니다.
Comment[lt]=Šis priedas integruoja PHP.net dokumentaciją esančią tinkle.
Comment[mr]=हा प्लगइन PHP.net ऑनलाइन दस्तऐवजीकरणाचे एकीकरण करतो.
Comment[ms]=Plugin ini mengintegrasikan dokumentasi dalam talian PHP.net
Comment[nb]=Dette programtillegget integrerer dokumentasjon på nettverket for PHP.net
Comment[nds]=Dit Moduul bett de Online-Dokmentatschoon vun PHP.net in.
Comment[nl]=Deze plugin integreert PHP.net online-documentatie.
Comment[pl]=Wtyczka ta integruje dokumentację internetową PHP.net.
Comment[pt]=Este 'plugin' integra a documentação 'online' do PHP.net.
Comment[pt_BR]=Este plugin integra a documentação online do PHP.net.
Comment[ru]=Расширение для работы с документацией с сайта PHP.net
Comment[sk]=Tento plugin integruje online dokumentáciu PHP.net.
Comment[sl]=Ta vstavek vključuje spletno dokumentacijo za PHP.
Comment[sv]=Insticksprogrammet integrerar PHP.net nätdokumentation.
Comment[tr]=Bu eklenti, PHP çevrimiçi belgelendirmesini entegre eder.
Comment[ug]=بۇ قىستۇرما PHP.net نىڭ توردىكى پۈتۈكلىرىنى يۈرۈشلەشتۈرىدۇ.
Comment[uk]=За допомогою цього додатка можна інтегрувати документацію PHP.net.
Comment[x-test]=xxThis plugin integrates PHP.net online documentation.xx
Comment[zh_CN]=此插件集成了 PHP.net 的在线文档。
Comment[zh_TW]=此外掛程式整合 PHP.net 線上文件。
Name=PHP Documentation
Name[bs]=PHP Dokumentacija
Name[ca]=Documentació de PHP
Name[ca@valencia]=Documentació de PHP
Name[cs]=Dokumentace PHP
Name[da]=PHP-dokumentation
Name[de]=PHP-Dokumentation
Name[el]=Τεκμηρίωση για PHP
Name[en_GB]=PHP Documentation
Name[es]=Documentación de PHP
Name[et]=PHP dokumentatsioon
Name[fi]=PHP-dokumentaatio
Name[fr]=Documentation de PHP
Name[ga]=Doiciméadú PHP
Name[gl]=Documentación de PHP
Name[hu]=PHP dokumentáció
Name[it]=Documentazione PHP
Name[ja]=PHP ドキュメント
Name[kk]=PHP құжаттамасы
Name[ko]=PHP 문서
Name[lt]=PHP dokumentacija
Name[mr]=पीएचपी दस्तऐवजीकरण
Name[ms]=Dokumentasi PHP
Name[nb]=PHP-dokumentasjon
Name[nds]=PHP-Dokmentatschoon
Name[nl]=PHP-documentatie
Name[pl]=Dokumentacja PHP
Name[pt]=Documentação de PHP
Name[pt_BR]=Documentação de PHP
Name[ru]=Документация по PHP
Name[sk]=Dokumentácia PHP
Name[sl]=Dokumentacija za PHP
Name[sv]=PHP-dokumentation
Name[tr]=PHP Belgelendirmesi
Name[ug]=PHP پۈتۈكلىرى
Name[uk]=Документація з PHP
Name[x-test]=xxPHP Documentationxx
Name[zh_CN]=PHP 文档
Name[zh_TW]=PHP 文件
ServiceTypes=KDevelop/Plugin

X-KDE-Library=kdevphpdocs
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevphpdocs
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Documentation
X-KDevelop-Mode=GUI
X-KDevelop-Interfaces=org.kdevelop.IDocumentationProvider
